;; Generated package description from fedi.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "fedi" "0.3.0.20260509.80041" "Helper functions for fediverse clients" '((emacs "28.1") (markdown-mode "2.5")) :commit "61fbd83977fe8b62e5e0337bc28e4cf8e1b32ea7" :authors '(("Marty Hiatt" . "martianh@disroot.org")) :maintainer '("Marty Hiatt" . "martianh@disroot.org") :url "https://codeberg.org/martianh/fedi.el")
